
# Slot: preconditions


an expression that must hold in order for the rule to be applicable to an instance

URI: [linkml:preconditions](https://w3id.org/linkml/preconditions)


## Domain and Range

None &#8594;  <sub>0..1</sub> [AnonymousClassExpression](AnonymousClassExpression.md)

## Parents


## Children


## Used by

 * [ClassRule](ClassRule.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | if |
|  | | body |
|  | | antecedents |
| **Mappings:** | | sh:condition |
| **Close Mappings:** | | swrl:body |

